<?php
/**
 * Tryo About Area Widget
 */

namespace Elementor;
class Tryo_About extends Widget_Base {

	public function get_name() {
        return 'Tryo_About';
    }

	public function get_title() {
        return __( 'About Area', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-user-circle-o';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_About',
			[
				'label' => __( 'About Area', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'image',
			[
				'label' => __( 'Choose Image', 'tryo-toolkit' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
        );
        
        $this->add_control(
            'top_title',
            [
                'label' => __( 'Top Title', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('How we were founded', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Easy, fee-free banking for entrepreneurs', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'desc',
            [
                'label' => esc_html__('Description', 'tryo-toolkit'),
                'type' => Controls_Manager::WYSIWYG,
            ]
        );

        $this->add_control(
            'video_link',
            [
                'label' => __( 'Video Link', 'tryo-toolkit' ),
                'type' => Controls_Manager::URL,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'top_title_color',
			[
				'label' => __( 'Top Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-content span' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_responsive_control(
			'top_title_size',
			[
				'label' => __( 'Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 30,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .about-content span' => 'font-size: {{SIZE}}px;',
				],
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-content h2' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_responsive_control(
			'title_size',
			[
				'label' => __( 'Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 60,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .about-content h2' => 'font-size: {{SIZE}}px;',
				],
			]
        );
        
        $this->add_control(
			'desc_color',
			[
				'label' => __( 'Description Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .about-content p' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_responsive_control(
			'desc_size',
			[
				'label' => __( 'Description Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 30,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}}  .about-content p' => 'font-size: {{SIZE}}px;',
				],
			]
        );

        $this->end_controls_section();
    }

	protected function render() {

		$settings = $this->get_settings_for_display();
		
		global $tryo_opt;
		if( isset( $tryo_opt['enable_lazyloader'] ) ):
			$is_lazyloader = $tryo_opt['enable_lazyloader'];
		else:
			$is_lazyloader = true;
		endif;

		if( $is_lazyloader == true ):
			$lazy_class = 'smartify';
			$lazy_attr = 'sm-';
		else:
			$lazy_class = '';
			$lazy_attr = '';
		endif;

        // Inline Editing
        $this-> add_inline_editing_attributes('top_title','none');
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('desc','none');
        ?>
        <div class="about-area ptb-70">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="about-content">
                            <span <?php echo $this-> get_render_attribute_string('top_title'); ?>><?php echo esc_html( $settings['top_title'] ); ?></span>
                            <h2 <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo esc_html( $settings['title'] ); ?></h2>
                            <?php echo $settings['desc']; ?>
                        </div>
                    </div>

                    <div class="col-lg-6 col-md-12">
                        <div class="about-image">
                            <img class="<?php echo esc_attr($lazy_class); ?>" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">

                            <?php if( $settings['video_link']['url'] != '' ): ?>
                                <a href="<?php echo esc_url( $settings['video_link']['url'] ); ?>" class="video-btn popup-youtube"><i class="fas fa-play"></i></a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_About );