<?php
/**
 * Tryo functions and definitions
 */

// Shorthand contents for theme assets url
define('TRYO_VERSION', time());
define('TRYO_THEME_URI', get_template_directory_uri());
define('TRYO_THEME_DIR', get_template_directory());
define('TRYO_IMG',TRYO_THEME_URI . '/assets/images');
define('TRYO_CSS',TRYO_THEME_URI . '/assets/css');
define('TRYO_JS',TRYO_THEME_URI . '/assets/js');
if( !defined('TRYO_FRAMEWORK_VAR') ) define('TRYO_FRAMEWORK_VAR', 'tryo_opt');

// Sets up theme defaults and registers support for various WordPress features.
if ( ! function_exists( 'tryo_setup' ) ) :

	function tryo_setup() {

		// make the theme available for translation
		$lang_dir = TRYO_THEME_URI . '/languages';
		load_theme_textdomain('tryo', $lang_dir);

		// add support for post formats
		add_theme_support('post-formats', [
			'standard', 'gallery', 'video', 'audio'
		]);

		// this theme styles the visual editor with editor-style.css to match the theme style.
		add_editor_style();

		// add support for automatic feed links
		add_theme_support('automatic-feed-links');

		// Enable support for yoast seo plugin
		add_theme_support( 'yoast-seo-breadcrumbs' );

		// let WordPress manage the document title
		add_theme_support( 'title-tag' );

		// add support for post thumbnails
		add_theme_support( 'post-thumbnails' );

		// Custom Image sizes for theme
		add_image_size( 'tryo_standard_card', 510, 400, true );
		add_image_size( 'tryo_blog_card', 750, 500, true );

		// register navigation menus
		register_nav_menus(
			[
				'primary' => esc_html__('Primary Menu', 'tryo'),
				'primarylogin' => esc_html__('User Register Menu', 'tryo'),
			]
		);

		// HTML5 markup support for search form, comment form, and comments
		add_theme_support( 'html5', array(
			'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
		) );

		// add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// enable support for wide alignment class for Gutenberg blocks.
		add_theme_support( 'align-wide' );

	}

endif;
add_action( 'after_setup_theme', 'tryo_setup' );

// set the content width in pixels, based on the theme's design and stylesheet.
if ( ! function_exists( 'tryo_content_width' ) ) :

	function tryo_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'tryo_content_width', 640 );
	}

endif;
add_action( 'after_setup_theme', 'tryo_content_width', 0 );

// enqueue scripts and styles for front-end.
if ( ! function_exists( 'tryo_scripts' ) ) :

	function tryo_scripts() {
		global $tryo_opt;

		if( isset( $tryo_opt['enable_lazyloader'] ) ):
			$is_lazyloader = $tryo_opt['enable_lazyloader'];
		else:
			$is_lazyloader = true;
		endif;

		if( isset( $tryo_opt['enable_minify_css_js'] ) ):
			$is_minify = $tryo_opt['enable_minify_css_js'];
		else:
			$is_minify = true;
		endif;

		wp_enqueue_style( 'tryo-style', get_stylesheet_uri() );
		wp_style_add_data( 'tryo-style', 'rtl', 'replace' );

		wp_enqueue_style( 'vendors', 			TRYO_CSS . '/vendors.min.css', null,TRYO_VERSION );
		wp_enqueue_style( 'all', 				TRYO_CSS . '/all.css', null,TRYO_VERSION );
		wp_enqueue_style( 'flat-icon', 			TRYO_CSS . '/flat-icon.css', null,TRYO_VERSION );
		wp_enqueue_style( 'nice-select', 		TRYO_CSS . '/nice-select.min.css', null,TRYO_VERSION );

		// WooCommerce CSS
		if ( class_exists( 'WooCommerce' ) ):
			if( $is_minify == true ):
				wp_enqueue_style( 'tryo-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.min.css');
			else :
				wp_enqueue_style( 'tryo-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce.css');
			endif;
		endif;

		if( $is_minify == true ):
			wp_enqueue_style( 'tryo-main-style', 	TRYO_CSS . '/style.min.css', null,TRYO_VERSION );
			wp_enqueue_style( 'tryo-responsive', 	TRYO_CSS . '/responsive.min.css', null,TRYO_VERSION );
		else :
			wp_enqueue_style( 'tryo-main-style', 	TRYO_CSS . '/style.css', null,TRYO_VERSION );
			wp_enqueue_style( 'tryo-responsive', 	TRYO_CSS . '/responsive.css', null,TRYO_VERSION );
		endif;

		// RTL CSS
		if( tryo_rtl() == true ):
			wp_enqueue_style( 'tryo-rtl', get_template_directory_uri() . '/rtl.css' );
		endif;

		wp_enqueue_script( 'vendors', 		    TRYO_JS . '/vendors.min.js', array('jquery'),TRYO_VERSION );

		// Smartify JS 
		if( $is_lazyloader == true ):
			wp_enqueue_script( 'jquery-smartify', 		TRYO_JS . '/jquery.smartify.js', array('jquery'),TRYO_VERSION );
			wp_enqueue_script( 'stike-smartify', 		TRYO_JS . '/smartify.js', array('jquery'),TRYO_VERSION );
		endif;

		// RTL JS
		if( tryo_rtl() == true ):
			if( $is_minify == true ):
				wp_enqueue_script( 'tryo-main', TRYO_JS . '/main-rtl.min.js', array('jquery'),TRYO_VERSION );
			else :
				wp_enqueue_script( 'tryo-main', TRYO_JS . '/main-rtl.js', array('jquery'),TRYO_VERSION );
			endif;
		else:
			if( $is_minify == true ):
				wp_enqueue_script( 'tryo-main', 		TRYO_JS . '/main.min.js', array('jquery'),TRYO_VERSION );
			else :
				wp_enqueue_script( 'tryo-main', 		TRYO_JS . '/main.js', array('jquery'),TRYO_VERSION );
			endif;
		endif;

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

	}
	
endif;
add_action( 'wp_enqueue_scripts', 'tryo_scripts' );

// Load google fonts
if ( ! function_exists( 'tryo_fonts' ) ) {
	function tryo_fonts() {
		wp_enqueue_style( 'tryo-fonts', "//fonts.googleapis.com/css?family=Raleway:400,500,600,700,800|Roboto:300,400,500,700&display=swap", '', '1.0.0', 'screen' );
	}
} // Endif function_exists()
add_action( 'wp_enqueue_scripts', 'tryo_fonts' );

// Custom template tags for this theme.
require TRYO_THEME_DIR . '/inc/template-tags.php';

// Functions which enhance the theme by hooking into WordPress.

require TRYO_THEME_DIR . '/inc/template-functions.php';

// Customizer additions.
require TRYO_THEME_DIR . '/inc/customizer.php';

// Load Jetpack compatibility file.
if ( defined( 'JETPACK__VERSION' ) ) {
	require TRYO_THEME_DIR . '/inc/jetpack.php';
}

// load bootstrap navwalker 
require TRYO_THEME_DIR . '/inc/bootstrap-navwalker.php';

// load theme widget 
require TRYO_THEME_DIR . '/inc/widget.php';

// Custom style
require TRYO_THEME_DIR . '/inc/custom-style.php';

// Social link
require TRYO_THEME_DIR . '/inc/social-link.php';

// Demo data import
require get_template_directory() . '/lib/demo-import.php';

// Recommended plugin
require get_template_directory() . '/lib/recommended-plugin.php';

// ACF meta filed
require get_template_directory() . '/inc/acf.php';

// Load WooCommerce compatibility file.
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

// Filter the categories archive widget to add a span around post count
if ( ! function_exists( 'tryo_cat_count_span' ) ) {
	function tryo_cat_count_span( $links ) {
		$links = str_replace( '</a> (', '</a><span class="post-count">(', $links );
		$links = str_replace( ')', ')</span>', $links );
		return $links;
	}
}
add_filter( 'wp_list_categories', 'tryo_cat_count_span' );

// Filter the archives widget to add a span around post count
if ( ! function_exists( 'tryo_archive_count_span' ) ) {
	function tryo_archive_count_span( $links ) {
		$links = str_replace( '</a>&nbsp;(', '</a><span class="post-count">(', $links );
		$links = str_replace( ')', ')</span>', $links );
		return $links;
	}
}
add_filter( 'get_archives_link', 'tryo_archive_count_span' );

// Excerpt more
if ( ! function_exists( 'tryo_excerpt_more' ) ) :
	function tryo_excerpt_more( $more ) {
		return ' ';
	}
endif;
add_filter('excerpt_more', 'tryo_excerpt_more');

// Search result
if ( ! function_exists( 'tryo_remove_pages_from_search' ) ) :
    function tryo_remove_pages_from_search() {
		global $wp_post_types;
		$wp_post_types['page']->exclude_from_search = true;
	}
endif;
add_action('init', 'tryo_remove_pages_from_search');

// If page edited by elementor
if ( ! function_exists( 'tryo_is_elementor' ) ) :
	function tryo_is_elementor(){
		if ( function_exists( 'elementor_load_plugin_textdomain' ) ):
			global $post;
			return \Elementor\Plugin::$instance->db->is_built_with_elementor($post->ID);
		endif;
	}
endif;

function tryo_app_output_buffer() {
    ob_start();
} // soi_output_buffer
add_action('init', 'tryo_app_output_buffer');

//Login
add_action('init', function(){

    // not the login request?
    if(!isset($_POST['action']) || $_POST['action'] !== 'my_login_action')
      return;
  
    // see the codex for wp_signon()
    $result = wp_signon();
  
    if(is_wp_error($result))
      wp_die('Login failed. Wrong password or user name?');
    // redirect back to the requested page if login was successful    
	wp_redirect( home_url( '/' ) );
	exit();

   // header('Location: ' . $_SERVER['REQUEST_URI']);
    exit;
});

if ( ! current_user_can('manage_options') ) {
	add_filter( 'show_admin_bar', '__return_false' );
}

/**
 * Classes
 */
require get_template_directory() . '/inc/classes/Tryo_base.php';
require get_template_directory() . '/inc/classes/Tryo_rt.php';
require get_template_directory() . '/inc/classes/Tryo_admin_page.php';
require get_template_directory() . '/inc/admin/dashboard/Tryo_admin_dashboard.php';

/**
 * Admin dashboard style and scripts
 */
add_action( 'admin_enqueue_scripts', function() {
    global $pagenow;
    wp_enqueue_script( 'tryo-admin', TRYO_JS.'/tryo-admin.js', array('jquery'), '1.0.0', true );
    if ( $pagenow == 'admin.php' ) {
		wp_enqueue_style( 'tryo-admin-dashboard', TRYO_CSS.'/admin-dashboard.min.css' );
    }
});

/**
 * Redirect after theme activation
 */
add_action( 'after_switch_theme', function() {
    if ( isset( $_GET['activated'] ) ) {
		wp_safe_redirect( admin_url('admin.php?page=tryo') );
		update_option( 'tryo_purchase_code_status', '', 'yes' );
		update_option( 'tryo_purchase_code', '', 'yes' );
        exit;
	}
	update_option('notice_dismissed', '0');
});

/**
 * Notice dismiss handle
 */
add_action( 'admin_init', function() {
    if ( isset($_GET['dismissed']) && $_GET['dismissed'] == 1 ) {
        update_option('notice_dismissed', '1');
    }
});