<?php
/**
 * Banner One Widget
 */

namespace Elementor;
class Tryo_Banner_One extends Widget_Base {

	public function get_name() {
        return 'Tryo_Banner_One';
    }

	public function get_title() {
        return __( 'Banner One', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_Banner_One_Area',
			[
				'label' => __( 'Tryo Banner Area', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'tryo-toolkit' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .main-banner',
			]
		);

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => __('Easy, fee-free banking for entrepreneurs', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'content',
            [
                'label' => __( 'Content', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Get the financial tools and insights to start, build, and grow your business.', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'button_text',
            [
				'label' => __( 'Button Text', 'tryo-toolkit' ),
				 
                'type' => Controls_Manager::TEXT,
                'default' => __('Get Started', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __( 'Button Link', 'tryo-toolkit' ),
                'type' => Controls_Manager::URL,
            ]
		);
		$this->add_control(
            'video_button_text',
            [
				'label' => __( 'Video Button Text', 'tryo-toolkit' ),
				 
                'type' => Controls_Manager::TEXT,
                'default' => __('Play Video', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'video_button_link',
            [
                'label' => __( 'Video Button Link', 'tryo-toolkit' ),
                'type' => Controls_Manager::URL,
            ]
		);

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .main-banner-content h1' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_responsive_control(
			'title_size',
			[
				'label' => __( 'Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 70,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .main-banner-content h1' => 'font-size: {{SIZE}}px;',
				],
			]
		);
        
        $this->add_control(
			'content_color',
			[
				'label' => __( 'Content Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .main-banner-content p' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_responsive_control(
			'content_size',
			[
				'label' => __( 'Content Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 50,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .main-banner-content p' => 'font-size: {{SIZE}}px;',
				],
			]
        );

        $this->add_responsive_control(
			'button_size',
			[
				'label' => __( 'Button Text Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 50,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .main-banner-content .btn' => 'font-size: {{SIZE}}px;',
				],
			]
		);

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();
		
        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');
        ?>
		<div class="main-banner jarallax" data-jarallax='{"speed": 0.3}'>
            <div class="d-table">
                <div class="d-table-cell">
                    <div class="container">
                        <div class="main-banner-content">
                            <h1 <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo esc_html( $settings['title'] ); ?></h1>
                            <p <?php echo $this-> get_render_attribute_string('content'); ?>><?php echo wp_kses_post( $settings['content'] ); ?></p>

							<div class="banner-btn">
								<?php if( $settings['button_text'] != '' ): ?>
									<a href="<?php echo esc_url( $settings['button_link']['url'] ); ?>" class="btn btn-primary">
										<?php echo esc_html( $settings['button_text'] ); ?>
									</a>
								<?php endif; ?>

								<?php if( $settings['video_button_text'] != '' ): ?>
									<a href="<?php echo esc_url( $settings['video_button_link']['url'] ); ?>" class="video-btn popup-youtube">
										<i class="fas fa-play"></i> 
										<?php echo esc_html( $settings['video_button_text'] ); ?>
									</a>
								<?php endif; ?>
							</div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Banner_One );