<?php
/**
 * Banner Three Widget
 */

namespace Elementor;
class Tryo_Banner_Three extends Widget_Base {

	public function get_name() {
        return 'Tryo_Banner_Three';
    }

	public function get_title() {
        return __( 'Banner Three', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_Banner_Three_Area',
			[
				'label' => __( 'Tryo Banner Area', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'tryo-toolkit' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .main-banner',
			]
        );
        
        $this->add_control(
			'image',
			[
				'label' => __( 'Banner Image', 'tryo-toolkit' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => __('Fast and easy business banking', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'content',
            [
                'label' => __( 'Content', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __('Get the financial tools and insights to start, build, and grow your business.', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'button_text',
            [
				'label' => __( 'Button Text', 'tryo-toolkit' ),
				 
                'type' => Controls_Manager::TEXT,
                'default' => __('Create your account', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __( 'Button Link', 'tryo-toolkit' ),
                'type' => Controls_Manager::URL,
            ]
        );

        $this->add_control(
            'video_button_text',
            [
				'label' => __( 'Video Button Text', 'tryo-toolkit' ),
				 
                'type' => Controls_Manager::TEXT,
                'default' => __(' Play Video', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'video_button_link',
            [
                'label' => __( 'Video Button Link', 'tryo-toolkit' ),
                'type' => Controls_Manager::URL,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
            'show_image_shape',
            [
                'label' => __( 'Show Image Shape', 'tryo' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'tryo' ),
                'label_off' => __( 'Hide', 'tryo' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-content h1' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_responsive_control(
			'title_size',
			[
				'label' => __( 'Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 70,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .hero-content h1' => 'font-size: {{SIZE}}px;',
				],
			]
		);
        
        $this->add_control(
			'content_color',
			[
				'label' => __( 'Content Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .hero-content p' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_responsive_control(
			'content_size',
			[
				'label' => __( 'Content Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 50,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .hero-content p' => 'font-size: {{SIZE}}px;',
				],
			]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        
        global $tryo_opt;
        if( isset( $tryo_opt['enable_lazyloader'] ) ):
            $is_lazyloader = $tryo_opt['enable_lazyloader'];
        else:
            $is_lazyloader = true;
        endif;

        if( $is_lazyloader == true ):
            $lazy_class = 'smartify';
            $lazy_attr = 'sm-';
        else:
            $lazy_class = '';
            $lazy_attr = '';
        endif;
		
        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');
        ?>
         <div class="banner-section">
            <div class="container">
                <div class="row m-0 align-items-center">
                    <div class="col-lg-5 col-md-12 p-0">
                        <div class="hero-content">
                            <h1 <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo esc_html( $settings['title'] ); ?></h1>
                            <p <?php echo $this-> get_render_attribute_string('content'); ?>><?php echo wp_kses_post( $settings['content'] ); ?></p>
                            <?php if( $settings['button_text'] != '' ): ?>
                            	<a href="<?php echo esc_url( $settings['button_link']['url'] );  ?>" class="btn btn-primary"><?php echo esc_html( $settings['button_text'] ); ?></a>
							<?php endif; ?>
                        </div>
                    </div>

                    <div class="col-lg-7 col-md-12 p-0">
                        <div class="hero-image">
                            <div class="main-image">
                                <?php if( $settings['image']['url'] == '' ): ?>
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( get_template_directory_uri() .'/assets/img/banner-image/1.png' ); ?>" data-wow-delay="0.7s" alt="<?php  echo esc_attr__( 'Hero Image' , 'tryo-toolkit' ); ?>">
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow fadeInLeft" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( get_template_directory_uri() .'/assets/img/banner-image/2.png' ); ?>" data-wow-delay="1.3s" alt="<?php  echo esc_attr__( 'Hero Image' , 'tryo-toolkit' ); ?>">
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow fadeInUp" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( get_template_directory_uri() .'/assets/img/banner-image/3.png' ); ?>" data-wow-delay="1s" alt="<?php  echo esc_attr__( 'Hero Image' , 'tryo-toolkit' ); ?>">
                                <?php else: ?>
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( $settings['image']['url'] ); ?>"  data-wow-delay="0.7s" alt="<?php  echo esc_attr__( 'Hero Image' , 'tryo-toolkit' ); ?>">
                                <?php endif; ?>
                                
                            </div>

                            <div class="main-mobile-image">
                                <?php if( $settings['image']['url'] == '' ): ?>
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( get_template_directory_uri() .'/assets/img/banner-image/main-pic.png' ); ?>" data-wow-delay="0.7s" alt="<?php  echo esc_attr__( 'Hero Image' , 'tryo-toolkit' ); ?>">
                                <?php else: ?>
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( $settings['image']['url'] ); ?>" data-wow-delay="0.7s" alt="<?php  echo esc_attr__( 'Hero Image' , 'tryo-toolkit' ); ?>">
                                <?php endif; ?>
                            </div>

                            <?php if( $settings['show_image_shape'] == 'yes' ): ?>
                                <div class="circle-image">
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow fadeInUp" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( get_template_directory_uri() .'/assets/img/banner-image/circle1.png' ); ?>" data-wow-delay="1s" alt="<?php  echo esc_attr__( 'Hero Image' , 'tryo-toolkit' ); ?>">
                                </div>
                            <?php endif; ?>

                            <?php if( $settings['video_button_text'] != '' ): ?>
                            	<a href="<?php echo esc_url( $settings['video_button_link']['url'] ); ?>" class="video-btn popup-youtube"><i class="fas fa-play"></i><?php echo esc_html( $settings['video_button_text'] ); ?></a>
							<?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Banner_Three );