<?php
/**
 * Tryo Business Area Widget
 */

namespace Elementor;
class Tryo_Business_Area extends Widget_Base {

	public function get_name() {
        return 'Tryo_Business_Area';
    }

	public function get_title() {
        return __( 'Business Area', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-text';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_Business_Area',
			[
				'label' => __( 'Support Area', 'tryo-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'image',
			[
				'label' => __( 'Section Image', 'tryo-toolkit' ),
				'type' => Controls_Manager::MEDIA,
			]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Made to grow with your business', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' 	=> esc_html__( 'Title Tag', 'tryo-toolkit' ),
                'type' 		=> Controls_Manager::SELECT,
                'options' 	=> [
                    'h1'         => esc_html__( 'h1', 'tryo-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'tryo-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'tryo-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'tryo-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'tryo-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'tryo-toolkit' ),
                ],
                'default' => 'h1',
            ]
        );

        $this->add_control(
            'items',
            [
                'type'    => Controls_Manager::REPEATER,
                'label'   => esc_html__( 'Add list items', 'tryo-toolkit' ),			                 
                'fields'  => array(				
                    array(
                        'type'    => Controls_Manager::TEXT,
                        'name'    => 'title',
                        'label'   => esc_html__( 'Title', 'tryo-toolkit' ),
                        'default' => 'International payments',
                    ),
                    array(
                        'type'    => Controls_Manager::TEXTAREA,
                        'name'    => 'desc',
                        'label'   => esc_html__( 'Description', 'tryo-toolkit' ),
                        'default' => 'Labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo.',
                    ),
                ),	
            ]			
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'bg_color',
			[
				'label' => __( 'Section Background Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} background-color' => 'background-color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .business-content h1, .business-content h2, .business-content h3, .business-content h4, .business-content h5, .business-content h6' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __( 'Title Typography', 'tryo-toolkit' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .business-content h1, .business-content h2, .business-content h3, .business-content h4, .business-content h5, .business-content h6',
            ]
        );

        
        $this->add_control(
			'list_color',
			[
				'label' => __( 'List Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .business-content .single-business-box h3' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'list_title_typography',
                'label' => __( 'List Title Typography', 'tryo-toolkit' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .business-content .single-business-box h3',
            ]
        );

        $this->add_control(
			'list_desc_color',
			[
				'label' => __( 'List Description Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .business-content .single-business-box p' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'list_desc_typography',
                'label' => __( 'List Description Typography', 'tryo-toolkit' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .business-content .single-business-box p',
            ]
        );

        $this->end_controls_section();
    }

	protected function render() {

		$settings = $this->get_settings_for_display();
		
		global $tryo_opt;
		if( isset( $tryo_opt['enable_lazyloader'] ) ):
			$is_lazyloader = $tryo_opt['enable_lazyloader'];
		else:
			$is_lazyloader = true;
		endif;

		if( $is_lazyloader == true ):
			$lazy_class = 'smartify';
			$lazy_attr = 'sm-';
		else:
			$lazy_class = '';
			$lazy_attr = '';
		endif;

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        ?>

        <div class="business-area ptb-70">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="business-content">
							<<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
								<?php echo esc_html( $settings['title'] ); ?>
							</<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <div class="row">
                                <?php foreach( $settings['items'] as $item ): ?>
                                    <div class="col-lg-6 col-md-6 col-sm-6">
                                        <div class="single-business-box">
                                            <h3><?php echo esc_html( $item['title'] ); ?></h3>
                                            <p><?php echo wp_kses_post( $item['desc'] ); ?></p>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>

                    <div class="col-lg-6 col-md-12">
                        <?php if( $settings['image']['url'] != '' ): ?>
                            <div class="business-image">
                                <img class="<?php echo esc_attr( $lazy_class ); ?>" <?php echo esc_attr( $lazy_attr ); ?>src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Business_Area );