<?php
/**
 * Contact CTA Widget
 */

namespace Elementor;
class Tryo_Contact_CTA extends Widget_Base {

	public function get_name() {
        return 'contact_cta';
    }

	public function get_title() {
        return __( 'Contact CTA', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-call-to-action';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_Contact_CTA',
			[
				'label' => __( 'Contact Cta Control', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'tryo-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Have any question about us?', 'tryo-toolkit'),
                'label_block' => true,
            ]
        );
        $this->add_control(
            'short_title',
            [
                'label' => esc_html__('Short Title', 'tryo-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Do not hesitate to contact us', 'tryo-toolkit'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'button_text',
            [
				'label' => __( 'Button Text', 'tryo-toolkit' ),
				 
                'type' => Controls_Manager::TEXT,
                'default' => __('Contact Us', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __( 'Button Link', 'tryo-toolkit' ),
                'type' => Controls_Manager::URL,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'contact_cta_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        
        $this->add_responsive_control(
			'contact_title_size',
			[
				'label' => __( 'Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 70,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}}  .contact-cta-box h3' => 'font-size: {{SIZE}}px;',
				],
			]
        );
        
        $this->add_control(
			'contact_title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .contact-cta-box h3' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_responsive_control(
			'contact_short_title_size',
			[
				'label' => __( 'Short Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 70,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}}  .contact-cta-box p' => 'font-size: {{SIZE}}px;',
				],
			]
        );
        
        $this->add_control(
			'contact_short_title_color',
			[
				'label' => __( 'Short Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .contact-cta-box p' => 'color: {{VALUE}}',
				],
			]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('short_title','none');

        ?>

        <div class="contact-cta-box">
            <h3 <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo esc_html( $settings['title'] ); ?></h3>
            <p <?php echo $this-> get_render_attribute_string('short_title'); ?>><?php echo esc_html( $settings['short_title'] ); ?></p>

            <?php if( $settings['button_text']  != '' ): ?>
                <a href="<?php echo esc_url( $settings['button_link']['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $settings['button_text'] ); ?></a>
            <?php endif; ?>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Contact_CTA );