<?php
/**
 * Fun-Facts Widget
 */

namespace Elementor;
class Tryo_FunFacts extends Widget_Base {

	public function get_name() {
        return 'funfacts';
    }

	public function get_title() {
        return __( 'FunFacts', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-flip-box';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_FunFacts',
			[
				'label' => __( 'FunFacts Control', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'count',
            [
                'label' => __( 'Counter Up', 'tryo-toolkit' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 245,
            ]
        );

        $this->add_control(
            'count_symbol',
            [
                'label' => __( 'Counter Symbol', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'K',
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'tryo-toolkit'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Downloaded', 'tryo-toolkit'),
                'label_block' => true,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'funfacts_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .funfact p' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_responsive_control(
			'title_size',
			[
				'label' => __( 'Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 20,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .funfact p' => 'font-size: {{SIZE}}px;',
				],
			]
        );
        
        $this->add_control(
			'counter_color',
			[
				'label' => __( 'Counter Up Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .funfact h3' => 'color: {{VALUE}}',
				],
			]
        );
        
        $this->add_responsive_control(
			'counter_size',
			[
				'label' => __( 'Counter Up Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 70,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}}  .funfact h3' => 'font-size: {{SIZE}}px;',
				],
			]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        ?>

        <div class="funfact">
            <h3><span class="odometer" data-count="<?php echo esc_attr( $settings['count'] ); ?>">00</span><?php echo esc_html( $settings['count_symbol'] ); ?></h3>
            <p <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo esc_html( $settings['title'] ); ?></p>
        </div>

        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_FunFacts );