<?php
/**
 * Tryo Global Area Widget
 */

namespace Elementor;
class Tryo_Global_Area extends Widget_Base {

	public function get_name() {
        return 'Tryo_Global_Area';
    }

	public function get_title() {
        return __( 'Global Area', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-text';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_Global_Area',
			[
				'label' => __( 'Global Area', 'tryo-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'image',
			[
				'label' => __( 'Section Image', 'tryo-toolkit' ),
				'type' => Controls_Manager::MEDIA,
			]
        );

        $this->add_control(
            'items',
            [
                'type'    => Controls_Manager::REPEATER,
                'label'   => esc_html__( 'Add list Item', 'tryo-toolkit' ),			                 
                'fields'  => array(	
                    array(
                        'type'    => Controls_Manager::TEXT,
                        'name'    => 'title',
                        'label'   => esc_html__( 'Title', 'tryo-toolkit' ),
                        'default' => '10 million customers',
                    ),	
                ),	
            ]			
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .global-content ul li' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __( 'Title Typography', 'tryo-toolkit' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .global-content ul li',
            ]
        );

        $this->end_controls_section();
    }

	protected function render() {

		$settings = $this->get_settings_for_display();
		
		global $tryo_opt;
		if( isset( $tryo_opt['enable_lazyloader'] ) ):
			$is_lazyloader = $tryo_opt['enable_lazyloader'];
		else:
			$is_lazyloader = true;
		endif;

		if( $is_lazyloader == true ):
			$lazy_class = 'smartify';
			$lazy_attr = 'sm-';
		else:
			$lazy_class = '';
			$lazy_attr = '';
		endif;

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        ?>
        <div class="container">
            <div class="row align-items-center">
                <div class="col-lg-5 col-md-12">
                    <div class="global-content">
                        <ul>
                            <?php foreach( $settings['items'] as $item ): ?>
                                <li><?php echo esc_html( $item['title'] ); ?></li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                </div>

                <div class="col-lg-7 col-md-12">
                    <?php if( $settings['image']['url'] != '' ): ?>
                        <div class="global-image text-center">
                            <img class="<?php echo esc_attr( $lazy_class ); ?>" <?php echo esc_attr( $lazy_attr ); ?>src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                        </div>
                    <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Global_Area );