<?php
/**
 * Invoicing Widget
 */

namespace Elementor;
class Tryo_Invoicing extends Widget_Base {

	public function get_name() {
        return 'Invoicing';
    }

	public function get_title() {
        return __( 'Invoicing Area', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-divider-shape';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Invoicing_section',
			[
				'label' => __( 'Invoicing Control', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
        
        $this->add_control(
			'title',
			[
				'label' => __( 'Title', 'tryo-toolkit' ),
				'type' => Controls_Manager::TEXT,
				'default' => __('Easy Payment to borrow free get a better filling at home', 'tryo-toolkit'),
			]
        );

        $this->add_control(
			'description',
			[
				'label' => __( 'Description', 'tryo-toolkit' ),
				'type' => Controls_Manager::WYSIWYG,
				'default' => __('Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip.', 'tryo-toolkit'),
			]
        );

        $this->add_control(
			'image',
			[
				'label' => __( 'Section Image', 'tryo-toolkit' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
        );

        $this->add_control(
            'button_text',
            [
				'label' => __( 'Button Text', 'tryo-toolkit' ),
				 
                'type' => Controls_Manager::TEXT,
                'default' => __('Get Started', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label' => __( 'Button Link', 'tryo-toolkit' ),
                'type' => Controls_Manager::URL,
            ]
        );
        
        $this->end_controls_section();

        $this->start_controls_section(
			'invoicing_style',
			[
				'label' => __( 'Invoicing Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .invoicing-content h2' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_responsive_control(
			'title_size',
			[
				'label' => __( 'Title Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 70,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .invoicing-content h2' => 'font-size: {{SIZE}}px;',
				],
			]
        );
        
        $this->add_control(
            'show_title_shape',
            [
                'label' => __( 'Show Title Animation', 'tryo' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'tryo' ),
                'label_off' => __( 'Hide', 'tryo' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );
        
        $this->add_control(
			'content_color',
			[
				'label' => __( 'Content Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .invoicing-content p' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
            'show_image_shape',
            [
                'label' => __( 'Show Image Animation', 'tryo' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'tryo' ),
                'label_off' => __( 'Hide', 'tryo' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_responsive_control(
			'content_size',
			[
				'label' => __( 'Content Font Size', 'tryo-toolkit' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 30,
						'step' => 1,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .invoicing-content p' => 'font-size: {{SIZE}}px;',
				],
			]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        global $tryo_opt;
        if( isset( $tryo_opt['enable_lazyloader'] ) ):
            $is_lazyloader = $tryo_opt['enable_lazyloader'];
        else:
            $is_lazyloader = true;
        endif;

        if( $is_lazyloader == true ):
            $lazy_class = 'smartify';
            $lazy_attr = 'sm-';
        else:
            $lazy_class = '';
            $lazy_attr = '';
        endif;

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('description','none');
        ?>

        <div class="invoicing-area ptb-70">
            <div class="container-fluid">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="invoicing-content">
                            <h2 <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo esc_html( $settings['title'] ); ?></h2>

                            <?php if( $settings['show_title_shape'] == 'yes' ): ?>
                                <div class="bar"></div>
                            <?php else: ?>
                                <br>
                            <?php endif; ?>

                            <p <?php echo $this-> get_render_attribute_string('description'); ?>><?php echo $settings['description']; ?></p>

                            <?php if( $settings['button_text'] != '' ): ?>
                                <a href="<?php echo esc_url( $settings['button_link']['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $settings['button_text'] ); ?></a>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div class="col-lg-6 col-md-12">
                        <div class="invoicing-image">
                            <div class="main-image">
                                <?php if( $settings['image']['url'] == '' ): ?>

                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn animated" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url(get_template_directory_uri() .'/assets/img/invoicing-image/1.png' ); ?>" data-wow-delay="0.7s" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>" style="visibility: visible; animation-delay: 0.7s; animation-name: zoomIn;">

                                    <img class="<?php echo esc_attr($lazy_class); ?> wow fadeInLeft animated" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url(get_template_directory_uri() .'/assets/img/invoicing-image/2.png' ); ?>" data-wow-delay="1s" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>" style="visibility: visible; animation-delay: 1s; animation-name: fadeInLeft;">

                                    <img class="<?php echo esc_attr($lazy_class); ?> wow fadeInLeft animated" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url(get_template_directory_uri() .'/assets/img/invoicing-image/3.png' ); ?>" data-wow-delay="1.3s" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>" style="visibility: visible; animation-delay: 1.3s; animation-name: fadeInLeft;">
                                    
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow fadeInRight animated" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url(get_template_directory_uri() .'/assets/img/invoicing-image/4.png' ); ?>" data-wow-delay="1s" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>" style="visibility: visible; animation-delay: 1s; animation-name: fadeInRight;">

                                <?php else: ?>
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn animated" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( $settings['image']['url'] ); ?>" data-wow-delay="0.7s" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>" style="visibility: visible; animation-delay: 0.7s; animation-name: zoomIn;">
                                <?php endif; ?>
                            </div>

                            <div class="main-mobile-image">
                                <?php if( $settings['image']['url'] == '' ): ?>
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url(get_template_directory_uri() .'/assets/img/invoicing-image/main-pic.png' ); ?>" data-wow-delay="0.7s" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>" style="animation-delay: 0.7s; animation-name: none;">
                                <?php else: ?>
                                    <img class="<?php echo esc_attr($lazy_class); ?> wow zoomIn" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url( $settings['image']['url'] ); ?>"  data-wow-delay="0.7s" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>" style="animation-delay: 0.7s; animation-name: none;">
                                <?php endif; ?>
                            </div>

                            <?php if( $settings['show_image_shape'] == 'yes' ): ?>
                                <div class="circle-image">
                                    <img class="<?php echo esc_attr($lazy_class); ?>" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url(get_template_directory_uri() .'/assets/img/invoicing-image/circle1.png' ); ?>" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>">
                                    <img class="<?php echo esc_attr($lazy_class); ?>" <?php echo esc_attr($lazy_attr); ?>src="<?php echo esc_url(get_template_directory_uri() .'/assets/img/invoicing-image/circle2.png' ); ?>" alt="<?php echo esc_attr__( 'invoicing', 'tryo' ); ?>">
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php 
        }

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Invoicing );