<?php
/**
 * Partner Logo Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Tryo_Partner_Logo extends Widget_Base {

	public function get_name() {
        return 'Partner_Logo';
    }

	public function get_title() {
        return __( 'Partner Slider', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-logo';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'partner_section',
			[
				'label' => __( 'Partner Logo Control', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'logos',
                [
                    'type'    => Controls_Manager::REPEATER,
                    'label'   => esc_html__( 'Add Partner Logo', 'tryo-toolkit' ),			                 
                    'fields'  => array(				
                        array(
                            'type'    => Controls_Manager::MEDIA,
                            'name'    => 'logo',
                            'label'   => esc_html__( 'Logo', 'tryo-toolkit' ),
                        ),
                    ),	
                ]			
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'partner_styling',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
            ]
        );	

            $this->add_responsive_control(
				'padding_top',
				[
					'label' => __( 'Padding Top', 'tryo-toolkit' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} .partner-area-two.ptb-70' => 'padding-top: {{SIZE}}px;',
					],
				]
            );
            
            $this->add_responsive_control(
				'padding_bottom',
				[
					'label' => __( 'Padding Bottom', 'tryo-toolkit' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 100,
							'step' => 1,
						],
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'selectors' => [
						'{{WRAPPER}} section.partner-area-two.ptb-70' => 'padding-bottom: {{SIZE}}px;',
					],
				]
			);
			
        $this->end_controls_section();

    }

	protected function render() {
        $settings = $this->get_settings_for_display();
        
        global $tryo_opt;
        if( isset( $tryo_opt['enable_lazyloader'] ) ):
            $is_lazyloader = $tryo_opt['enable_lazyloader'];
        else:
            $is_lazyloader = true;
        endif;

        if( $is_lazyloader == true ):
            $lazy_class = 'smartify';
            $lazy_attr = 'sm-';
        else:
            $lazy_class = '';
            $lazy_attr = '';
        endif;
        ?>
            <div class="partner-area-two ptb-70">
                <div class="container">
                    <div class="partner-slides owl-carousel owl-theme">
                        <?php foreach( $settings['logos'] as $item ): ?>
                            <div class="single-partner-item-new">
                                <img class="<?php echo esc_attr( $lazy_class ); ?>" <?php echo esc_attr( $lazy_attr ); ?>src="<?php echo esc_url( $item['logo']['url'] ); ?>" alt="<?php echo esc_attr( 'Partner Area', 'tryo-toolkit' ); ?>">
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>       
        <?php
	}
	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Partner_Logo );