<?php
/**
 * Tryo Payment Experience Area Widget
 */

namespace Elementor;
class Tryo_Payment_Experience_Area  extends Widget_Base {

	public function get_name() {
        return 'Tryo_Payment_Experience_Area ';
    }

	public function get_title() {
        return __( 'Payment Experience Area', 'tryo-toolkit' );
    }

	public function get_icon() {
        return 'eicon-user-circle-o';
    }

	public function get_categories() {
        return [ 'tryo-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Tryo_Payment_Experience_Area ',
			[
				'label' => __( 'Payment Experience Area', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'style',
            [
                'label' 	=> esc_html__( 'Select Style', 'tryo-toolkit' ),
                'type' 		=> Controls_Manager::SELECT,
                'options' 	=> [
                    '1'         => esc_html__( 'Style One', 'tryo-toolkit' ),
                    '2'         => esc_html__( 'Style Two', 'tryo-toolkit' ),
                    '3'         => esc_html__( 'Style Three', 'tryo-toolkit' ),
                ],
                'default' => '1',
            ]
        );

        $this->add_control(
			'image',
			[
				'label' => __( 'Section Image', 'tryo-toolkit' ),
				'type' => Controls_Manager::MEDIA,
			]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'tryo-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Create seamless payment experiences', 'tryo-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' 	=> esc_html__( 'Title Tag', 'tryo-toolkit' ),
                'type' 		=> Controls_Manager::SELECT,
                'options' 	=> [
                    'h1'         => esc_html__( 'h1', 'tryo-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'tryo-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'tryo-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'tryo-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'tryo-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'tryo-toolkit' ),
                ],
                'default' => 'h1',
            ]
        );

        $this->add_control(
            'desc',
            [
                'label' => esc_html__('Description', 'tryo-toolkit'),
                'type' => Controls_Manager::WYSIWYG,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_style',
			[
				'label' => __( 'Style', 'tryo-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'tryo-toolkit' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .payment-features-overview .payment-features-content .content h1, .payment-features-overview .payment-features-content .content h2, .payment-features-overview .payment-features-content .content h3, .payment-features-overview .payment-features-content .content h4, .payment-features-overview .payment-features-content .content h5, .payment-features-overview .payment-features-content .content h6' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => __( 'Title Typography', 'tryo-toolkit' ),
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .payment-features-overview .payment-features-content .content h1, .payment-features-overview .payment-features-content .content h2, .payment-features-overview .payment-features-content .content h3, .payment-features-overview .payment-features-content .content h4, .payment-features-overview .payment-features-content .content h5, .payment-features-overview .payment-features-content .content h6',
            ]
        );
       
        $this->end_controls_section();
    }

	protected function render() {

		$settings = $this->get_settings_for_display();
		
		global $tryo_opt;
		if( isset( $tryo_opt['enable_lazyloader'] ) ):
			$is_lazyloader = $tryo_opt['enable_lazyloader'];
		else:
			$is_lazyloader = true;
		endif;

		if( $is_lazyloader == true ):
			$lazy_class = 'smartify';
			$lazy_attr = 'sm-';
		else:
			$lazy_class = '';
			$lazy_attr = '';
		endif;

        // Inline Editing
        $this-> add_inline_editing_attributes('top_title','none');
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('desc','none');
        ?>

        <?php if( $settings['style'] == '1' ): ?>
            <div class="row align-items-center">
                <div class="col-lg-5 col-md-12">
                    <div class="payment-experience-content">
                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                            <?php echo esc_html( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                        <?php echo wp_kses_post( $settings['desc'] ); ?>
                    </div>
                </div>

                <div class="col-lg-7 col-md-12">
                    <div class="payment-experience-image text-center">
                        <?php if( $settings['image']['url'] != '' ): ?>
                            <img src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <?php if( $settings['style'] == '2' ): ?>
            <div class="payment-features-overview">
                    <?php if( $settings['image']['url'] != '' ): ?>
                        <div class="payment-features-image">
                            <div class="image">
                                <img src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="payment-features-content">
                        <div class="content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                            <?php echo wp_kses_post( $settings['desc'] ); ?>
                        </div>
                    </div>
                </div>
        <?php endif; ?>

        <?php if( $settings['style'] == '3' ): ?>
            <div class="payment-features-overview">
                <div class="payment-features-content payment-features-content-two">
                    <div class="content">
                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                            <?php echo esc_html( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                        <?php echo wp_kses_post( $settings['desc'] ); ?>
                    </div>
                </div>

                <?php if( $settings['image']['url'] != '' ): ?>
                    <div class="payment-features-image payment-features-image-two">
                        <div class="image">
                            <img src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                        </div>
                    </div>
                <?php endif; ?>
            </div>
        <?php endif; ?>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register_widget_type( new Tryo_Payment_Experience_Area  );