<?php
/**
 * The header for our theme
 * @package Tryo
 */
global $tryo_opt;
?>
<!doctype html>
<?php if( tryo_rtl() == true ): ?>
	<html dir="rtl" <?php language_attributes(); ?>>
<?php else: ?>
	<html <?php language_attributes(); ?>>
<?php endif; ?>

<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php tryo_preloader(); ?> <!-- Preloader -->

	<?php
	if ( function_exists('acf_add_options_page') ) {
		$nevbar_style = get_field( 'nevbar_style' );
	} else {
		$nevbar_style = 'style_one';
	}

	$hide_adminbar 		= 'hide-adminbar';
	$navbar_style_two 	= 'navbar-style-two';

	// Login Button
	if( isset( $tryo_opt['login_register_title'] ) ):
		$login_register_title 		= $tryo_opt['login_register_title'];
		$logout_title 		        = $tryo_opt['logout_title'];
		$login_register_link_type 	= $tryo_opt['login_register_link_type'];
		// Page link
		$login_register_link 		= get_page_link($login_register_link_type);
	else:
		$login_register_title 		= '';
		$logout_title 		        = '';
		$login_register_link_type 	= '';
		$login_register_link 		= '';
	endif;

	if( isset($tryo_opt['welcome_text']) ):
		$call_number           = $tryo_opt['call_number'];
		$call_number_link      = $tryo_opt['call_number_link'];
		$address               = $tryo_opt['address'];
		$email                 = $tryo_opt['email'];
		$email_link            = $tryo_opt['email_link'];
		$welcome_text          = $tryo_opt['welcome_text'];
	else:
		$call_number           = '';
		$call_number_link      = '';
		$address               = '';
		$welcome_text          = '';
		$email                 = '';
		$email_link            = '';
	endif;
	?>

	<header class="header-area <?php if ( is_user_logged_in() && current_user_can('manage_options') ) { echo esc_attr( $hide_adminbar ); }?>">
		<?php if( isset( $tryo_opt['hide_top_header'] ) && $tryo_opt['hide_top_header'] != 1 ){
			if( $welcome_text || $call_number || $address || $email ){ 
				?>
				<div class="top-header">
					<div class="container">
						<div class="row align-items-center">
							<div class="col-lg-3">
								<div class="header-left-content">
									<p><?php echo esc_html($welcome_text); ?></p>
								</div>
							</div>
							<div class="col-lg-9">
								<div class="header-right-content">
									<ul>
										<?php if( $call_number !='' ){ ?>
											<li>
												<a href="<?php echo esc_url( $call_number_link ); ?>">
													<i class='fa fa-phone'></i>
													<?php echo esc_html( $call_number ); ?>
												</a>
											</li> <?php
										} ?>
										<?php if( $address !='' ){ ?>
											<li>
												<i class='fa fa-location-arrow'></i>
												<?php echo esc_html( $address ); ?>
											</li><?php
										} ?>
										<?php if( $email !='' ){ ?>
											<li>
												<a href="<?php echo esc_url( $email_link ); ?>">
													<i class='fa fa-envelope-o'></i>
													<?php echo esc_html( $email ); ?>
												</a>
											</li> <?php
										} ?>
									</ul>
								</div>
							</div>
						</div>
					</div>
				</div>
			<?php 
			} 
		} ?>
		
		<div class="navbar-area <?php if( $nevbar_style == 'style_two' ){ echo esc_attr( $navbar_style_two ); } ?> "><!-- Start Navbar Area -->
			<div class="luvion-responsive-nav">
				<div class="container">
					<div class="luvion-responsive-menu">
						<div class="logo">
							<a href="<?php echo esc_url( home_url( '/' ) ); ?>">
								<?php tryo_main_logo(); ?>
								<?php tryo_sticky_logo(); ?>
							</a>
						</div>
					</div>
				</div>
			</div>

			<div class="luvion-nav">
				<div class="container">
					<nav class="navbar navbar-expand-md navbar-light">
						<a class="navbar-brand" href="<?php echo esc_url( home_url( '/' ) ); ?>">
							<?php 
							if( $nevbar_style == 'style_two' ){ 
								tryo_sticky_logo();
							}else {
								tryo_main_logo();
								tryo_sticky_logo();
							} ?>
						</a>

						<div class="collapse navbar-collapse mean-menu" id="navbarSupportedContent">
							<?php if( is_user_logged_in() ){
								tryo_main_nav_login();
							} else {
								tryo_main_nav();
							} ?>

							<div class="others-options">
								<?php if( isset( $tryo_opt['enable_cart_btn'] ) && $tryo_opt['enable_cart_btn'] == true ) {
									if ( class_exists( 'WooCommerce' ) ) { ?>
										<a class="cart-btn" href="<?php echo esc_url( wc_get_cart_url() ) ?>">
											<i class='fa fa-shopping-bag'></i>
											<span class="mini-cart-count"></span>
										</a><?php 
									}
								} ?>
								<?php if ( $login_register_title != '' || $logout_title != '' ) : ?>
									<?php if( is_user_logged_in() ): ?>
										<a href="<?php echo wp_logout_url( home_url() ); ?>" class="login-btn">
											<i class="flaticon-user"></i>
											<?php echo esc_html( $logout_title ); ?>
										</a>
									<?php else: ?>
										<a href="<?php echo esc_url( $login_register_link ); ?>" class="login-btn">
											<i class="flaticon-user"></i>
											<?php echo esc_html( $login_register_title ); ?>
										</a>											
									<?php endif; ?>
								<?php endif; ?>
							</div>
							
						</div>
					</nav>
				</div>
			</div>
		</div><!-- End Navbar Area -->
	</header>
	
